import os
import traceback
import zipfile
from pathlib import Path

import js
import nltk
from pyodide.ffi.wrappers import add_event_listener

from main import check_naming_convention  # type: ignore[attr-defined]

editor_input = js.ace.edit("editor-input")
editor_input.setOption("maxLines", float("inf"))
editor_output = js.ace.edit("editor-output")
editor_output.setOption("maxLines", float("inf"))
editor_output.setReadOnly(True)


def on_click_help_button(_: None) -> None:
    help_dialog = js.document.getElementById("help-dialog")
    help_dialog.showModal()


def on_keyup_editor_input(_: None) -> None:
    editor_input_value = editor_input.getValue()
    try:
        output = check_naming_convention(editor_input_value.encode("utf-8"))
        editor_output.setValue("\n".join(output))
    except SyntaxError:
        editor_output.setValue(traceback.format_exc())


async def on_change_file_input(e) -> None:  # type: ignore[no-untyped-def] # noqa: ANN001
    file_list = e.target.files
    first_item = file_list.item(0)
    editor_input.setValue(await first_item.text())
    on_keyup_editor_input(None)


def main() -> None:
    os.environ["NLTK_DATA"] = "tmp/nltk_data"
    nltk.data.path = ["tmp/nltk_data", *nltk.data.path]
    zipfile.ZipFile("tmp/nltk_data/taggers/averaged_perceptron_tagger.zip").extractall(
        path="tmp/nltk_data/taggers/",
    )
    zipfile.ZipFile("tmp/nltk_data/tokenizers/punkt.zip").extractall(
        path="tmp/nltk_data/tokenizers/",
    )
    zipfile.ZipFile("tmp/nltk_data/corpora/wordnet.zip").extractall(
        path="tmp/nltk_data/corpora/",
    )
    zipfile.ZipFile("tmp/nltk_data/corpora/words.zip").extractall(
        path="tmp/nltk_data/corpora/",
    )
    with Path("main.py").open() as file:
        editor_input.setValue(file.read())
    on_keyup_editor_input(None)
    add_event_listener(
        js.document.getElementById("editor-input"),
        "keyup",
        on_keyup_editor_input,
    )
    add_event_listener(
        js.document.getElementById("file-input"),
        "change",
        on_change_file_input,
    )
    add_event_listener(
        js.document.getElementById("help-button"),
        "click",
        on_click_help_button,
    )


if __name__ == "__main__":
    main()
